@@ -1446,8 +1446,8 @@ int c, intermediate;
 		  else
 		    {
 		      if (curr->w_alt.on) {
-		        RestoreCursor(&curr->w_alt.cursor);
 		        LeaveAltScreen(curr);
+		        RestoreCursor(&curr->w_alt.cursor);
 		      }
 		    }
 		  if (a1 == 47 && !i)
@@ -2906,6 +2906,8 @@ struct mline *ml;
 
   if (++wp->w_histidx >= wp->w_histheight)
     wp->w_histidx = 0;
+  if (wp->w_scrollback_height < wp->w_histheight)
+    ++wp->w_scrollback_height;
 }
 #endif
 
