@@ -27,6 +27,7 @@
  */
 
 #include "config.h"
+#include <stdbool.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
@@ -58,6 +59,10 @@ extern char *SockName, *SockMatch, SockPath[];
 extern char HostName[];
 extern struct passwd *ppp;
 extern char *attach_tty, *attach_term, *LoginName, *preselect;
+/* Indicator whether the current tty exists in another namespace. */
+extern bool attach_tty_is_in_new_ns;
+/* Content of the tty symlink when attach_tty_is_in_new_ns == true. */
+extern char attach_tty_name_in_ns[];
 extern int xflag, dflag, rflag, quietflag, adaptflag;
 extern struct mode attach_Mode;
 extern struct NewWindow nwin_options;
@@ -115,11 +120,11 @@ int s;
 struct msg *m;
 {
   int r, l = sizeof(*m);
+  bool is_socket;
 
-#ifndef NAMEDPIPE
-  if (m->type == MSG_ATTACH)
+  is_socket = IsSocket(SockPath);
+  if (is_socket && m->type == MSG_ATTACH)
     return SendAttachMsg(s, m, attach_fd);
-#endif
 
   while(l > 0)
     {
@@ -142,6 +147,7 @@ int how;
   struct msg m;
   struct stat st;
   char *s;
+  bool is_socket;
 
   debug2("Attach: how=%d, tty=%s\n", how, attach_tty);
 #ifdef MULTIUSER
@@ -226,12 +232,13 @@ int how;
   bzero((char *) &m, sizeof(m));
   m.type = how;
   m.protocol_revision = MSG_REVISION;
-  strncpy(m.m_tty, attach_tty, sizeof(m.m_tty) - 1);
+  strncpy(m.m_tty, attach_tty_is_in_new_ns ? attach_tty_name_in_ns : attach_tty, sizeof(m.m_tty) - 1);
   m.m_tty[sizeof(m.m_tty) - 1] = 0;
 
+  is_socket = IsSocket(SockPath);
   if (how == MSG_WINCH)
     {
-      if ((lasts = MakeClientSocket(0)) >= 0)
+      if ((lasts = MakeClientSocket(0, is_socket)) >= 0)
 	{
 	  WriteMessage(lasts, &m);
           close(lasts);
@@ -241,7 +248,7 @@ int how;
 
   if (how == MSG_CONT)
     {
-      if ((lasts = MakeClientSocket(0)) < 0)
+      if ((lasts = MakeClientSocket(0, is_socket)) < 0)
         {
           Panic(0, "Sorry, cannot contact session \"%s\" again.\r\n",
                  SockName);
@@ -249,7 +256,7 @@ int how;
     }
   else
     {
-      n = FindSocket(&lasts, (int *)0, (int *)0, SockMatch);
+      n = FindSocket(&lasts, (int *)0, (int *)0, SockMatch, &is_socket);
       switch (n)
 	{
 	case 0:
@@ -358,7 +365,7 @@ int how;
       if (how != MSG_ATTACH)
 	return 0;	/* we detached it. jw. */
       sleep(1);	/* we dont want to overrun our poor backend. jw. */
-      if ((lasts = MakeClientSocket(0)) == -1)
+      if ((lasts = MakeClientSocket(0, is_socket)) == -1)
 	Panic(0, "Cannot contact screen again. Sigh.");
       m.type = how;
     }
@@ -474,6 +481,7 @@ AttacherFinit SIGDEFARG
   struct stat statb;
   struct msg m;
   int s;
+  bool is_socket;
 
   debug("AttacherFinit();\n");
   signal(SIGHUP, SIG_IGN);
@@ -482,13 +490,14 @@ AttacherFinit SIGDEFARG
     {
       debug("Detaching backend!\n");
       bzero((char *) &m, sizeof(m));
-      strncpy(m.m_tty, attach_tty, sizeof(m.m_tty) - 1);
+      strncpy(m.m_tty, attach_tty_is_in_new_ns ? attach_tty_name_in_ns : attach_tty, sizeof(m.m_tty) - 1);
       m.m_tty[sizeof(m.m_tty) - 1] = 0;
       debug1("attach_tty is %s\n", attach_tty);
       m.m.detach.dpid = getpid();
       m.type = MSG_HANGUP;
       m.protocol_revision = MSG_REVISION;
-      if ((s = MakeClientSocket(0)) >= 0)
+      is_socket = IsSocket(SockPath);
+      if ((s = MakeClientSocket(0, is_socket)) >= 0)
 	{
           WriteMessage(s, &m);
 	  close(s);
@@ -997,10 +1006,11 @@ int query;
   struct msg m;
   char *p;
   int len, n;
+  bool is_socket;
 
   if (sty == 0)
     {
-      i = FindSocket(&s, (int *)0, (int *)0, match);
+      i = FindSocket(&s, (int *)0, (int *)0, match, &is_socket);
       if (i == 0)
 	Panic(0, "No screen session found.");
       if (i != 1)
@@ -1015,14 +1025,15 @@ int query;
       if (strlen(sty) > 2 * MAXSTR - 1)
 	sty[2 * MAXSTR - 1] = 0;
       sprintf(SockPath + strlen(SockPath), "/%s", sty);
-      if ((s = MakeClientSocket(1)) == -1)
+      is_socket = IsSocket(SockPath);
+      if ((s = MakeClientSocket(1, is_socket)) == -1)
 	exit(1);
     }
   bzero((char *)&m, sizeof(m));
   m.type = query ? MSG_QUERY : MSG_COMMAND;
   if (attach_tty)
     {
-      strncpy(m.m_tty, attach_tty, sizeof(m.m_tty) - 1);
+      strncpy(m.m_tty, attach_tty_is_in_new_ns ? attach_tty_name_in_ns : attach_tty, sizeof(m.m_tty) - 1);
       m.m_tty[sizeof(m.m_tty) - 1] = 0;
     }
   p = m.m.command.cmd;
@@ -1055,7 +1066,7 @@ int query;
 	{
 	  query[6] = c;
 	  strcpy(sp, query);	/* XXX: strncpy? */
-	  if ((r = MakeServerSocket()) >= 0)
+	  if ((r = MakeServerSocket(is_socket)) >= 0)
 	    break;
 	}
       if (r < 0)
@@ -1064,7 +1075,7 @@ int query;
 	    {
 	      query[6] = c;
 	      strcpy(sp, query);
-	      if ((r = MakeServerSocket()) >= 0)
+	      if ((r = MakeServerSocket(is_socket)) >= 0)
 		break;
 	    }
 	}
