@@ -533,6 +533,6 @@
 #define ORIGIN "GNU"
 #define REV 4
 #define VERS 6
-#define PATCHLEVEL 0
-#define DATE "28-Jun-17"
+#define PATCHLEVEL 1
+#define DATE "10-Jul-17"
 #define STATE ""
